@@ -44,6 +44,9 @@ class HeaderToLabelMiddleware(object):
     def __get_time_in_milliseconds(self):
         return int(round(time.time() * 1000))
 
+    def __is_debug(self):
+        return logger.getLevel().lower() != "info"
+
     def _get_header(self, request, header_name):
         return request.META.get(header_name, DEFAULT_HEADER_VALUE)
 
@@ -81,7 +84,8 @@ class HeaderToLabelMiddleware(object):
             log_entry_info[label] = header_value
             log_entry_debug[label] = header_value
 
-        logger.debug('', log_entry_debug)
+        if self.__is_debug() != "":
+            logger.info('', log_entry_debug)
         logger.info('', log_entry_info)
 
     def process_response(self, request, response):
@@ -118,11 +122,12 @@ class HeaderToLabelMiddleware(object):
             log_entry_info[label] = getattr(request, label)
 
         if response.status_code < 400:
-            logger.debug(
-                '', extra=log_entry
-            )
+            if self.__is_debug() != "":
+                logger.info(
+                    '', extra=log_entry
+                )
         else:
-            logger.error(
+            logger.info(
                 '', extra=log_entry
             )
 
@@ -163,7 +168,7 @@ class HeaderToLabelMiddleware(object):
             log_entry[label] = getattr(request, label)
             log_entry_info[label] = getattr(request, label)
 
-        logger.error(
+        logger.info(
             '', extra=log_entry
         )
         logger.info(
